@@ -17,8 +17,8 @@ from webviz_subsurface._models import ParametersModel
 from webviz_subsurface._providers import (
     EnsembleSummaryProvider,
     EnsembleSummaryProviderFactory,
+    EnsembleTableProvider,
     EnsembleTableProviderFactory,
-    EnsembleTableProviderSet,
     Frequency,
     get_matching_vector_names,
 )
@@ -167,11 +167,16 @@ Responses are extracted automatically from the `.arrow` files in the individual
                 for ens in ensembles
             }
             table_provider_factory = EnsembleTableProviderFactory.instance()
+
             parameterdf = create_df_from_table_provider(
-                table_provider_factory.create_provider_set_from_per_realization_parameter_file(
-                    self.ens_paths
-                )
+                provider_set={
+                    ens_name: table_provider_factory.create_from_per_realization_parameter_file(
+                        ens_path
+                    )
+                    for ens_name, ens_path in self.ens_paths.items()
+                }
             )
+
             if self.response_file:
                 self.responsedf = load_csv(
                     ensemble_paths=self.ens_paths,
@@ -409,19 +414,13 @@ Responses are extracted automatically from the `.arrow` files in the individual
                         children=[
                             wcc.Selectors(
                                 label="Controls", children=self.control_layout
-                            )
-                        ]
-                        + (
-                            [
-                                wcc.Selectors(
-                                    label="Filters",
-                                    id=self.uuid("filters"),
-                                    children=self.filter_layout,
-                                )
-                            ]
-                            if self.response_filters
-                            else []
-                        ),
+                            ),
+                            wcc.Selectors(
+                                label="Filters",
+                                id=self.uuid("filters"),
+                                children=self.filter_layout,
+                            ),
+                        ],
                     ),
                 ),
                 wcc.FlexColumn(
@@ -778,14 +777,14 @@ def read_csv(csv_file) -> pd.DataFrame:
     return pd.read_csv(csv_file, index_col=False)
 
 
-def create_df_from_table_provider(provider: EnsembleTableProviderSet) -> pd.DataFrame:
+def create_df_from_table_provider(
+    provider_set: Dict[str, EnsembleTableProvider]
+) -> pd.DataFrame:
     """Aggregates parameters from all ensemble into a common dataframe."""
     dfs = []
-    for ens in provider.ensemble_names():
-        df = provider.ensemble_provider(ens).get_column_data(
-            column_names=provider.ensemble_provider(ens).column_names()
-        )
-        df["ENSEMBLE"] = df.get("ENSEMBLE", ens)
+    for ens_name, provider in provider_set.items():
+        df = provider.get_column_data(column_names=provider.column_names())
+        df["ENSEMBLE"] = ens_name
         dfs.append(df)
     return pd.concat(dfs)
 
