@@ -58,6 +58,16 @@ def distribution_controllers(
             if item in volumemodel.parameters and item not in parameters:
                 parameters.append(item)
 
+        # for bo/bg the data should be grouped on fluid zone
+        if any(x in selected_data for x in ["BO", "BG"]) and "FLUID_ZONE" not in groups:
+            if "BO" in selected_data and "BG" in selected_data:
+                return html.Div(
+                    "Can't plot BO against BG", style={"margin-top": "40px"}
+                )
+            selections["filters"]["FLUID_ZONE"] = [
+                "oil" if "BO" in selected_data else "gas"
+            ]
+
         dframe = volumemodel.get_df(
             filters=selections["filters"], groups=groups, parameters=parameters
         )
@@ -352,8 +362,13 @@ def make_tables(
         statcols = ["Mean", "Stddev", "P90", "P10", "Min", "Max"]
         groups = [x for x in groups if x != "REAL"]
         responses = [x for x in responses if x != "REAL" and x is not None]
-        df_groups = dframe.groupby(groups) if groups else [(None, dframe)]
 
+        if not groups:
+            df_groups = [("", dframe)]
+        elif len(groups) == 1:
+            df_groups = dframe.groupby(groups[0])
+        else:
+            df_groups = dframe.groupby(groups)
         data_properties = []
         data_volcols = []
         for response in responses:
@@ -373,10 +388,11 @@ def make_tables(
                     data.update(
                         FLUID_ZONE=(" + ").join(selections["filters"]["FLUID_ZONE"])
                     )
-
                 for idx, group in enumerate(groups):
                     data[group] = (
-                        name if not isinstance(name, tuple) else list(name)[idx]
+                        name
+                        if name is not None or name is not isinstance(name, str)
+                        else list(name)[idx]
                     )
                 if response in volumemodel.volume_columns:
                     data["Response"] = response
