@@ -1,7 +1,8 @@
 from typing import List, Optional
 
-import dash_html_components as html
 import webviz_core_components as wcc
+from dash import html
+
 from webviz_subsurface._models import InplaceVolumesModel
 
 
@@ -10,7 +11,7 @@ def filter_layout(
     tab: str,
     volumemodel: InplaceVolumesModel,
     open_details: bool = True,
-    filters: Optional[list] = None,
+    hide_selectors: Optional[list] = None,
 ) -> wcc.Selectors:
     """Layout for selecting intersection data"""
     return wcc.Selectors(
@@ -18,7 +19,10 @@ def filter_layout(
         open_details=open_details,
         children=[
             filter_dropdowns(
-                uuid=uuid, tab=tab, volumemodel=volumemodel, filters=filters
+                uuid=uuid,
+                tab=tab,
+                volumemodel=volumemodel,
+                hide_selectors=hide_selectors,
             ),
             realization_filters(uuid=uuid, tab=tab, volumemodel=volumemodel),
         ],
@@ -29,30 +33,77 @@ def filter_dropdowns(
     uuid: str,
     volumemodel: InplaceVolumesModel,
     tab: str,
-    filters: Optional[list] = None,
+    hide_selectors: Optional[list] = None,
 ) -> html.Div:
     """Makes dropdowns for each selector"""
-    dropdowns: List[html.Div] = []
-    filters = filters if filters is not None else volumemodel.selectors
-    for selector in filters:
-        if selector == "REAL":
-            continue
-        elements = list(volumemodel.dataframe[selector].unique())
-
-        dropdowns.append(
-            html.Div(
-                style={"display": "inline" if len(elements) > 1 else "none"},
-                children=wcc.SelectWithLabel(
-                    label=selector.lower().capitalize(),
-                    id={"id": uuid, "tab": tab, "selector": selector},
-                    options=[{"label": i, "value": i} for i in elements],
-                    value=elements,
-                    multi=True,
-                    size=min(15, len(elements)),
-                ),
+    dropdowns_layout: List[html.Div] = []
+    hide_selectors = ["SENSNAME", "SENSTYPE", "SENSCASE"] + (
+        hide_selectors if hide_selectors is not None else []
+    )
+    selectors = [
+        x
+        for x in volumemodel.selectors
+        if x not in volumemodel.region_selectors + ["REAL"]
+    ]
+    for selector in selectors:
+        dropdowns_layout.append(
+            create_filter_select(
+                selector,
+                elements=list(volumemodel.dataframe[selector].unique()),
+                filter_type="undef",
+                uuid=uuid,
+                tab=tab,
+                hide=selector in hide_selectors,
             )
         )
-    return html.Div(dropdowns)
+    # Make region filters
+    dropdowns_layout.append(
+        html.Span("Region filters: ", style={"font-weight": "bold"})
+    )
+    if all(x in volumemodel.region_selectors for x in ["FIPNUM", "ZONE", "REGION"]):
+        dropdowns_layout.append(fipnum_vs_zone_region_switch(uuid, tab))
+
+    for selector in volumemodel.region_selectors:
+        dropdowns_layout.append(
+            create_filter_select(
+                selector,
+                elements=list(volumemodel.dataframe[selector].unique()),
+                filter_type="region",
+                uuid=uuid,
+                tab=tab,
+                hide=selector == "FIPNUM" and len(volumemodel.region_selectors) > 1,
+            )
+        )
+    return html.Div(dropdowns_layout)
+
+
+def create_filter_select(
+    selector: str, elements: list, uuid: str, tab: str, filter_type: str, hide: bool
+) -> html.Div:
+    return html.Div(
+        id={"id": uuid, "tab": tab, "wrapper": selector, "type": filter_type},
+        style={"display": "inline" if len(elements) > 1 and not hide else "none"},
+        children=wcc.SelectWithLabel(
+            label=selector.lower().capitalize(),
+            id={"id": uuid, "tab": tab, "selector": selector, "type": filter_type},
+            options=[{"label": i, "value": i} for i in elements],
+            value=elements,
+            multi=True,
+            size=min(15, len(elements)),
+        ),
+    )
+
+
+def fipnum_vs_zone_region_switch(uuid: str, tab: str) -> wcc.RadioItems:
+    return wcc.RadioItems(
+        id={"id": uuid, "tab": tab, "element": "region-selector"},
+        options=[
+            {"label": "Region∕Zone", "value": "regzone"},
+            {"label": "Fipnum", "value": "fipnum"},
+        ],
+        value="regzone",
+        vertical=False,
+    )
 
 
 def realization_filters(
@@ -100,7 +151,7 @@ def realization_filters(
             html.Div(
                 style={"display": "none"},
                 children=wcc.Select(
-                    id={"id": uuid, "tab": tab, "selector": "REAL"},
+                    id={"id": uuid, "tab": tab, "selector": "REAL", "type": "REAL"},
                     options=[{"label": i, "value": i} for i in reals],
                     value=reals,
                 ),
